@@ -2,14 +2,20 @@
 
 from __future__ import print_function
 
-from .ssh_config import ConfigParser
-from .exceptions import StormValueError
-
 from operator import itemgetter
+import re
 
-import getpass
+from .parsers.ssh_config_parser import ConfigParser
+from .defaults import get_default
+
+
+__version__ = '0.6.4'
+
+ERRORS = {
+    "already_in": "{0} is already in your sshconfig. use storm edit or storm update to modify.",
+    "not_found": "{0} doesn\'t exists in your sshconfig. use storm add command to add.",
+}
 
-__version__ = '0.6.2'
 
 
 class Storm(object):
@@ -17,10 +23,11 @@ class Storm(object):
     def __init__(self, ssh_config_file=None):
         self.ssh_config = ConfigParser(ssh_config_file)
         self.ssh_config.load()
+        self.defaults = self.ssh_config.defaults
 
     def add_entry(self, name, host, user, port, id_file, custom_options=[]):
         if self.is_host_in(name):
-            raise StormValueError('{0} is already in your sshconfig. use storm edit command to modify.'.format(name))
+            raise ValueError(ERRORS["already_in"].format(name))
 
         options = self.get_options(host, user, port, id_file, custom_options)
 
@@ -29,22 +36,37 @@ class Storm(object):
 
         return True
 
+    
+    def clone_entry(self, name, clone_name):
+        host = self.is_host_in(name, return_match=True)
+        if not host:
+            raise ValueError(ERRORS["not_found"].format(name))
+
+        # check if an entry with the clone name already exists        
+        if name == clone_name or self.is_host_in(clone_name, return_match=True) is not None:
+            raise ValueError(ERRORS["already_in"].format(clone_name))
+       
+        self.ssh_config.add_host(clone_name, host.get('options'))
+        self.ssh_config.write_to_ssh_config()
+
+        return True
+
     def edit_entry(self, name, host, user, port, id_file, custom_options=[]):
         if not self.is_host_in(name):
-            raise StormValueError('{0} doesn\'t exists in your sshconfig. use storm add command to add.'.format(name))
+            raise ValueError(ERRORS["not_found"].format(name))
 
         options = self.get_options(host, user, port, id_file, custom_options)
 
-        self.ssh_config.update_host(name, options)
+        self.ssh_config.update_host(name, options, use_regex=False)
         self.ssh_config.write_to_ssh_config()
 
         return True
 
     def update_entry(self, name, **kwargs):
-        if not self.is_host_in(name):
-            raise StormValueError('{0} doesn\'t exists in your sshconfig. use storm add command to add.'.format(name))
+        if not self.is_host_in(name, regexp_match=True):
+            raise ValueError(ERRORS["not_found"].format(name))
 
-        self.ssh_config.update_host(name, kwargs)
+        self.ssh_config.update_host(name, kwargs, use_regex=True)
         self.ssh_config.write_to_ssh_config()
 
         return True
@@ -83,9 +105,9 @@ class Storm(object):
         for host_entry in results:
             formatted_results.append("    {0} -> {1}@{2}:{3}\n".format(
                 host_entry.get("host"),
-                host_entry.get("options").get("user", getpass.getuser()),
-                host_entry.get("options").get("hostname"),
-                host_entry.get("options").get("port", 22),
+                host_entry.get("options").get("user", get_default("user", self.defaults)),
+                host_entry.get("options").get("hostname", "[hostname_not_specified]"),
+                host_entry.get("options").get("port", get_default("port", self.defaults)),
             ))
 
         return formatted_results
@@ -108,14 +130,13 @@ class Storm(object):
                     key, value = custom_option.split("=")
 
                     options.update({
-                        key: value,
+                        key.lower() : value,
                     })
 
         return options
 
-    def is_host_in(self, host):
-        import re
+    def is_host_in(self, host, return_match = False, regexp_match=False):
         for host_ in self.ssh_config.config_data:
-            if host_.get("host") == host or re.match(host, host_.get("host")):
-                return True
-        return False
+            if host_.get("host") == host or (regexp_match and re.match(host, host_.get("host"))):
+                return True if not return_match else host_
+        return False if not return_match else None
